==> unicore-gateway-6.4.0-2.src.tar.gz: src/main/java/eu/unicore/gateway/properties/GatewayProperties.java <==
/**
 * Copyright (c) 2005, Forschungszentrum Juelich
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met: 
 * 
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the Forschungszentrum Juelich nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package eu.unicore.gateway.properties;

import java.io.File;
import java.util.HashSet;
import java.util.Set;

import org.apache.log4j.Logger;

import eu.unicore.gateway.base.IProxyCertificateValidator;
import eu.unicore.gateway.util.LogUtil;
import eu.unicore.gateway.util.ProtocolPluginHandler;

public class GatewayProperties extends RProperties
{
	private static final Logger log = LogUtil.getLogger(LogUtil.GATEWAY,
		GatewayProperties.class);

	public static final File FILE_GATEWAY_PROPERTIES = new File("conf" + File.separator
		+ "gateway.properties");

	public static final String KEY_HOSTNAME = "hostname";
	public static final String KEY_CONSIGNORT_TOLERANCE = "consignorTokenTimeTolerance";
	public static final String KEY_CONSIGNORT_VALIDITY = "consignorTokenValidity";
	public static final String KEY_CONSIGNORT_SIGN = "signConsignorToken";
	public static final String KEY_CHUNKED = "http.connection.chunked";
	// external address (e.g. when using apache as frontend web server)
	public static final String KEY_EXTERNAL_ADDRESS = "gateway.external.hostname";
	public static final String KEY_REG_ENABLED = "registration.enable";
	public static final String KEY_WEBPAGE_DISABLE = "webpage.disable";
	public static final String KEY_PROXY_AUTH = "proxyAuthentication";
	public static final String KEY_PROTOCOL_PLUGIN_PFX = "protocolPlugin.";
	public static final String KEY_PROXY_VALIDATOR = "proxyValidator";
	public static final String KEY_REG_INCL = "registration.allow";
	public static final String KEY_REG_EXCL = "registration.deny";

	public static final String KEY_SOCKET_TIMEOUT = "http.socket.timeout";
	public static final String KEY_CONN_TIMEOUT = "http.connection.timeout";
	public static final String KEY_CONN_KEEPALIVE = "http.connection.keep-alive";
	public static final String KEY_CONN_GZIP = "http.connection.gzip";
	public static final String KEY_PROTO_EXPECTCONTINUE = "http.protocol.expect-continue";
	public static final String KEY_CONN_MAX_TOTAL = "http.connection.maxTotal";
	public static final String KEY_CONN_MAX_PERHOST = "http.connection.maxPerService";

	// defaults for the consignor SAML assertion
	public static int DEFAULT_TOLERANCE = 30;
	public static final int DEFAULT_VALIDITY = 60;
	public static final boolean DEFAULT_SIGN = false;
	// default proxy validator class name
	public static final String DEFAULT_PROXY_VALIDATOR = "eu.unicore.proxy.RFC3820ProxyValidator";

	private static final Set<String> REQ_PROPERTIES = new HashSet<String>();
	static 
	{
		REQ_PROPERTIES.add(KEY_HOSTNAME);
	}


	public GatewayProperties(String name)
	{
		super(name, REQ_PROPERTIES);
	}

	public GatewayProperties(File f)
	{
		super(f, REQ_PROPERTIES);
	}

	
	
	
	
	public int getSocketTimeout()
	{
		return getPropertyAsInt(KEY_SOCKET_TIMEOUT, 1000000);
	}
	
	public int getConnectionTimeout()
	{
		return getPropertyAsInt(KEY_CONN_TIMEOUT, 1000000);
	}

	public boolean isKeepAlive()
	{
		return getPropertyAsBool(KEY_CONN_KEEPALIVE, true);
	}

	public boolean isGzipEnabled()
	{
		return getPropertyAsBool(KEY_CONN_GZIP, true);
	}
	
	public boolean isExpectContinueEnabled()
	{
		return getPropertyAsBool(KEY_PROTO_EXPECTCONTINUE, true);
	}

	public int getMaxTotalConnections()
	{
		return getPropertyAsInt(KEY_CONN_MAX_TOTAL, 100);
	}
	public int getMaxPerServiceConnections()
	{
		return getPropertyAsInt(KEY_CONN_MAX_PERHOST, 20);
	}	
	
	public String getHostname()
	{
		return getStringProperty(GatewayProperties.KEY_HOSTNAME);
	}
	
	public String getExternalHostname()
	{
		return getStringProperty(GatewayProperties.KEY_EXTERNAL_ADDRESS, null);
	}
	
	public int getConsTTol()
	{
		return getPropertyAsInt(KEY_CONSIGNORT_TOLERANCE, 
			0, Integer.MAX_VALUE, GatewayProperties.DEFAULT_TOLERANCE, log);
	}
	
	public int getConsTVal()
	{
		return getPropertyAsInt(KEY_CONSIGNORT_VALIDITY, 
			1, Integer.MAX_VALUE, GatewayProperties.DEFAULT_VALIDITY, log);
	}
	
	public boolean isConsTSign()
	{
		return getPropertyAsBool(KEY_CONSIGNORT_SIGN, GatewayProperties.DEFAULT_SIGN);
	}
	
	public boolean isDynamicRegistrationEnabled() 
	{
		return getPropertyAsBool(KEY_REG_ENABLED, false);
	}
	
	public boolean isDetailedWebPageDisabled() 
	{
		return getPropertyAsBool(KEY_WEBPAGE_DISABLE, false);
	}
	
	public boolean isProxyEnabled()
	{
		return getPropertyAsBool(KEY_PROXY_AUTH, false);
	}

	/**
	 * get the class name of a particular protocol handler
	 * @param name - the name of the protocol (should be in upper case!)
	 * @return the name of a Java class implementing {@link ProtocolPluginHandler}
	 */
	public String getProtocolPluginHandler(String name)
	{
		String pv = getStringProperty(KEY_PROTOCOL_PLUGIN_PFX + name.toUpperCase());
		return pv;
	}
	
	/**
	 * return the configured {@link IProxyCertificateValidator} class name,
	 * or the default one {@link GatewayProperties#DEFAULT_PROXY_VALIDATOR}
	 * 
	 * @return proxy validator class name
	 */
	public String getProxyValidator()
	{
		return getStringProperty("proxyValidator", DEFAULT_PROXY_VALIDATOR);
	}
	
	public boolean isChunkedDispatch()
	{
		return getPropertyAsBool(KEY_CHUNKED, true);
	}
	
	public String getRegistrationExcludes()
	{
		return getStringProperty(KEY_REG_EXCL, null);
	}

	public String getRegistrationIncludes()
	{
		return getStringProperty(KEY_REG_INCL, null);
	}
	
	public void setProperty(String key,String value){
		properties.setProperty(key, value);
	}
}

==> unicore-gateway6-4.3.0-2.src.tar.gz: src/main/java/eu/unicore/gateway/properties/GatewayProperties.java <==
/**
 * Copyright (c) 2005, Forschungszentrum Juelich
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met: 
 * 
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the Forschungszentrum Juelich nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package eu.unicore.gateway.properties;

import java.io.File;
import java.util.HashSet;
import java.util.Set;

import org.apache.log4j.Logger;

import eu.unicore.gateway.base.IProxyCertificateValidator;
import eu.unicore.gateway.util.LogUtil;
import eu.unicore.gateway.util.ProtocolPluginHandler;

public class GatewayProperties extends RProperties
{
	private static final Logger log = LogUtil.getLogger(LogUtil.GATEWAY,
		GatewayProperties.class);

	public static final File FILE_GATEWAY_PROPERTIES = new File("conf" + File.separator
		+ "gateway.properties");

	public static final String KEY_HOSTNAME = "hostname";
	public static final String KEY_CONSIGNORT_TOLERANCE = "consignorTokenTimeTolerance";
	public static final String KEY_CONSIGNORT_VALIDITY = "consignorTokenValidity";
	public static final String KEY_CONSIGNORT_SIGN = "signConsignorToken";
	public static final String KEY_CHUNKED = "http.connection.chunked";
	// external address (e.g. when using apache as frontend web server)
	public static final String KEY_EXTERNAL_ADDRESS = "gateway.external.hostname";
	public static final String KEY_REG_ENABLED = "registration.enable";
	public static final String KEY_WEBPAGE_DISABLE = "webpage.disable";
	public static final String KEY_PROXY_AUTH = "proxyAuthentication";
	public static final String KEY_PROTOCOL_PLUGIN_PFX = "protocolPlugin.";
	public static final String KEY_PROXY_VALIDATOR = "proxyValidator";
	public static final String KEY_REG_INCL = "registration.allow";
	public static final String KEY_REG_EXCL = "registration.deny";

	public static final String KEY_SOCKET_TIMEOUT = "http.socket.timeout";
	public static final String KEY_CONN_TIMEOUT = "http.connection.timeout";
	public static final String KEY_CONN_KEEPALIVE = "http.connection.keep-alive";
	public static final String KEY_CONN_GZIP = "http.connection.gzip";
	public static final String KEY_PROTO_EXPECTCONTINUE = "http.protocol.expect-continue";
	public static final String KEY_CONN_MAX_TOTAL = "http.connection.maxTotal";
	public static final String KEY_CONN_MAX_PERHOST = "http.connection.maxPerService";

	public static final String KEY_MAX_HEADER = "soapMaxHeader";
	
	// defaults for the consignor SAML assertion
	public static final int DEFAULT_TOLERANCE = 30;
	public static final int DEFAULT_VALIDITY = 60;
	public static final boolean DEFAULT_SIGN = false;
	// default proxy validator class name
	public static final String DEFAULT_PROXY_VALIDATOR = "eu.unicore.proxy.RFC3820ProxyValidator";
	// default limit for the SOAP header size
	public static final int DEFAULT_MAX_HDR = 102400;
	
	private static final Set<String> REQ_PROPERTIES = new HashSet<String>();
	static 
	{
		REQ_PROPERTIES.add(KEY_HOSTNAME);
	}


	public GatewayProperties(String name)
	{
		super(name, REQ_PROPERTIES);
	}

	public GatewayProperties(File f)
	{
		super(f, REQ_PROPERTIES);
	}

	
	
	
	
	public int getSocketTimeout()
	{
		return getPropertyAsInt(KEY_SOCKET_TIMEOUT, 1000000);
	}
	
	public int getConnectionTimeout()
	{
		return getPropertyAsInt(KEY_CONN_TIMEOUT, 1000000);
	}

	public boolean isKeepAlive()
	{
		return getPropertyAsBool(KEY_CONN_KEEPALIVE, true);
	}

	public boolean isGzipEnabled()
	{
		return getPropertyAsBool(KEY_CONN_GZIP, true);
	}
	
	public boolean isExpectContinueEnabled()
	{
		return getPropertyAsBool(KEY_PROTO_EXPECTCONTINUE, true);
	}

	public int getMaxTotalConnections()
	{
		return getPropertyAsInt(KEY_CONN_MAX_TOTAL, 100);
	}
	public int getMaxPerServiceConnections()
	{
		return getPropertyAsInt(KEY_CONN_MAX_PERHOST, 20);
	}	
	
	public String getHostname()
	{
		return getStringProperty(GatewayProperties.KEY_HOSTNAME);
	}
	
	public String getExternalHostname()
	{
		return getStringProperty(GatewayProperties.KEY_EXTERNAL_ADDRESS, null);
	}
	
	public int getConsTTol()
	{
		return getPropertyAsInt(KEY_CONSIGNORT_TOLERANCE, 
			0, Integer.MAX_VALUE, GatewayProperties.DEFAULT_TOLERANCE, log);
	}
	
	public int getConsTVal()
	{
		return getPropertyAsInt(KEY_CONSIGNORT_VALIDITY, 
			1, Integer.MAX_VALUE, GatewayProperties.DEFAULT_VALIDITY, log);
	}
	
	public boolean isConsTSign()
	{
		return getPropertyAsBool(KEY_CONSIGNORT_SIGN, GatewayProperties.DEFAULT_SIGN);
	}
	
	public boolean isDynamicRegistrationEnabled() 
	{
		return getPropertyAsBool(KEY_REG_ENABLED, false);
	}
	
	public boolean isDetailedWebPageDisabled() 
	{
		return getPropertyAsBool(KEY_WEBPAGE_DISABLE, false);
	}
	
	public boolean isProxyEnabled()
	{
		return getPropertyAsBool(KEY_PROXY_AUTH, false);
	}

	/**
	 * get the class name of a particular protocol handler
	 * @param name - the name of the protocol (should be in upper case!)
	 * @return the name of a Java class implementing {@link ProtocolPluginHandler}
	 */
	public String getProtocolPluginHandler(String name)
	{
		String pv = getStringProperty(KEY_PROTOCOL_PLUGIN_PFX + name.toUpperCase());
		return pv;
	}
	
	/**
	 * return the configured {@link IProxyCertificateValidator} class name,
	 * or the default one {@link GatewayProperties#DEFAULT_PROXY_VALIDATOR}
	 * 
	 * @return proxy validator class name
	 */
	public String getProxyValidator()
	{
		return getStringProperty("proxyValidator", DEFAULT_PROXY_VALIDATOR);
	}
	
	public boolean isChunkedDispatch()
	{
		return getPropertyAsBool(KEY_CHUNKED, true);
	}
	
	public String getRegistrationExcludes()
	{
		return getStringProperty(KEY_REG_EXCL, null);
	}

	public String getRegistrationIncludes()
	{
		return getStringProperty(KEY_REG_INCL, null);
	}
	
	public int getMaxSoapHeader()
	{
		return getPropertyAsInt(KEY_MAX_HEADER, 1024, 1024000000, DEFAULT_MAX_HDR, log);
	}
	
	public void setProperty(String key,String value){
		properties.setProperty(key, value);
	}
}
